==> haskell-foldable1-classes-compat-0.1-133-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-foldable1-classes-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 foldable1-classes-compat
version:              0.1
visibility:           public
id:                   foldable1-classes-compat-0.1-H7nUQumZ4OyBi9hV0l4Ooi
key:                  foldable1-classes-compat-0.1-H7nUQumZ4OyBi9hV0l4Ooi
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Edward Kmett, Oleg Grenrus
homepage:             https://github.com/haskell-compat/foldable1-classes-compat
synopsis:
    Compatibility package for the Foldable1 and Bifoldable1 type classes

description:
    A compatibility package for the @Foldable1@ and @Bifoldable1@ type classes,
    which were introduced in @base-4.18.0.0@ (GHC 9.6.1). For more information,
    see <https://github.com/haskell/core-libraries-committee/issues/9 this Core
    Libraries Committee proposal>.

    @Foldable1@ and @Bifoldable1@ classify non-empty data structures that can be
    folded to a summary value.

category:             Data, Compatibility
abi:                  b73532ac6d74666ee8f426392bb79952
exposed:              True
exposed-modules:      Data.Bifoldable1 Data.Foldable1
import-dirs:          /usr/lib/ghc-9.4.8/site-local/foldable1-classes-compat-0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/foldable1-classes-compat-0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/foldable1-classes-compat-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-foldable1-classes-compat
hs-libraries:         HSfoldable1-classes-compat-0.1-H7nUQumZ4OyBi9hV0l4Ooi
depends:
    base-4.17.2.1 containers-0.6.7 ghc-prim-0.9.1
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-foldable1-classes-compat/html/foldable1-classes-compat.haddock

haddock-html:         /usr/share/doc/haskell-foldable1-classes-compat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-foldable1-classes-compat-0.1-135-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-foldable1-classes-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 foldable1-classes-compat
version:              0.1
visibility:           public
id:                   foldable1-classes-compat-0.1-GCuELUEGi3b4CxiSDhoSht
key:                  foldable1-classes-compat-0.1-GCuELUEGi3b4CxiSDhoSht
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Edward Kmett, Oleg Grenrus
homepage:             https://github.com/haskell-compat/foldable1-classes-compat
synopsis:
    Compatibility package for the Foldable1 and Bifoldable1 type classes

description:
    A compatibility package for the @Foldable1@ and @Bifoldable1@ type classes,
    which were introduced in @base-4.18.0.0@ (GHC 9.6.1). For more information,
    see <https://github.com/haskell/core-libraries-committee/issues/9 this Core
    Libraries Committee proposal>.

    @Foldable1@ and @Bifoldable1@ classify non-empty data structures that can be
    folded to a summary value.

category:             Data, Compatibility
abi:                  11667d7cbde9e391dd13217dcd0b6d59
exposed:              True
exposed-modules:      Data.Bifoldable1 Data.Foldable1
import-dirs:          /usr/lib/ghc-9.4.8/site-local/foldable1-classes-compat-0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/foldable1-classes-compat-0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/foldable1-classes-compat-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-foldable1-classes-compat
hs-libraries:         HSfoldable1-classes-compat-0.1-GCuELUEGi3b4CxiSDhoSht
depends:
    base-4.17.2.1 containers-0.6.7 ghc-prim-0.9.1
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-foldable1-classes-compat/html/foldable1-classes-compat.haddock

haddock-html:         /usr/share/doc/haskell-foldable1-classes-compat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
